@@ -283,8 +283,6 @@ class TestRepozeWho1AuthenticationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthenticationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthenticationPolicy)
         self.assertEqual(policy.callback, None)
         self.assertEqual(policy.identifier_name, 'auth_tkt')
@@ -300,8 +298,6 @@ class TestRepozeWho1AuthenticationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthenticationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthenticationPolicy)
         self.assertEqual(policy.callback, callback)
         self.assertEqual(policy.identifier_name, 'something')
@@ -329,8 +325,6 @@ class TestRemoteUserAuthenticationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthenticationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthenticationPolicy)
         self.assertEqual(policy.environ_key, 'REMOTE_USER')
         self.assertEqual(policy.callback, None)
@@ -346,8 +340,6 @@ class TestRemoteUserAuthenticationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthenticationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthenticationPolicy)
         self.assertEqual(policy.environ_key, 'BLAH')
         self.assertEqual(policy.callback, callback)
@@ -373,8 +365,6 @@ class TestAuthTktAuthenticationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthenticationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthenticationPolicy)
         self.assertEqual(policy.cookie.secret, 'sosecret')
         self.assertEqual(policy.callback, None)
@@ -393,8 +383,6 @@ class TestAuthTktAuthenticationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthenticationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthenticationPolicy)
         self.assertEqual(policy.cookie.path, '/sub/')
         self.assertEqual(policy.cookie.http_only, True)
@@ -426,8 +414,6 @@ class TestACLAuthorizationPolicyDirective(unittest.TestCase):
         self.assertEqual(len(actions), 1)
         regadapt = actions[0]
         self.assertEqual(regadapt['discriminator'], IAuthorizationPolicy)
-        self.assertEqual(regadapt['callable'], None)
-        self.assertEqual(regadapt['args'], ())
         policy = reg.getUtility(IAuthorizationPolicy)
         self.assertEqual(policy.__class__, ACLAuthorizationPolicy)
 
@@ -655,11 +641,15 @@ class TestStaticDirective(unittest.TestCase):
         actions = extract_actions(context.actions)
         self.assertEqual(len(actions), 2)
 
-        route_action = actions[0]
+        if hasattr(self.config, 'add_response_adapter'):
+            # 1.1 +
+            route_action, view_action = actions[0], actions[1]
+        else:
+            view_action, route_action = actions[0], actions[1]
+
         discriminator = route_action['discriminator']
         self.assertEqual(discriminator[:2], ('route', 'name/',))
 
-        view_action = actions[1]
         discriminator = view_action['discriminator']
         self.assertEqual(discriminator[:1], ('view',))
         self.assertEqual(discriminator[4], IView)
@@ -679,7 +669,6 @@ class TestStaticDirective(unittest.TestCase):
         self.assertEqual(view(None, request).__class__, PackageURLParser)
 
     def test_it_with_nondefault_permission(self):
-        from pyramid import testing
         from pyramid.exceptions import Forbidden
         self.config.testing_securitypolicy(permissive=False)
         from zope.interface import implementedBy
@@ -694,11 +683,15 @@ class TestStaticDirective(unittest.TestCase):
         actions = extract_actions(context.actions)
         self.assertEqual(len(actions), 2)
 
-        route_action = actions[0]
+        if hasattr(self.config, 'add_response_adapter'):
+            # 1.1 +
+            route_action, view_action = actions[0], actions[1]
+        else:
+            view_action, route_action = actions[0], actions[1]
+
         discriminator = route_action['discriminator']
         self.assertEqual(discriminator[:2], ('route', 'name/'))
 
-        view_action = actions[1]
         discriminator = view_action['discriminator']
         self.assertEqual(discriminator[:1], ('view',))
         self.assertEqual(discriminator[4], IView)
@@ -837,11 +830,15 @@ class TestZCMLScanDirective(unittest.TestCase):
         return scan(context, package)
 
     def test_it(self):
+        class DummyVenusianCategories(dict):
+            def attached_to(self, ob):
+                return True
         dummy_module = DummyModule()
         def foo(): pass
         def bar(scanner, name, ob):
             dummy_module.scanned = True
-        foo.__venusian_callbacks__ = {'pyramid':[bar]}
+        categories = DummyVenusianCategories({'pyramid':[bar]})
+        foo.__venusian_callbacks__ = categories
         dummy_module.foo = foo
         
         context = self.config._ctx
